@@ -3,7 +3,7 @@ package Mail::MtPolicyd;
 use strict;
 use base qw(Net::Server::PreFork);
 
-our $VERSION = '1.19'; # VERSION
+our $VERSION = '1.20'; # VERSION
 # ABSTRACT: a modular policy daemon for postfix
 
 use Data::Dumper;
@@ -256,7 +256,7 @@ sub child_init_hook {
 
     # close parent database connection
     if( Mail::MtPolicyd::SqlConnection->is_initialized ) {
-        Mail::MtPolicyd::SqlConnection->disconnect;
+        Mail::MtPolicyd::SqlConnection->reconnect;
     }
 
 	$self->{'memcached'} = Cache::Memcached->new( {
@@ -435,7 +435,8 @@ sub _process_one_request {
 
 		# convert to ms and round by 0.5/int
 		my $elapsed = int(tv_interval( $start_t, [gettimeofday] ) * 100 + 0.5);
-		$self->log(1, $vhost->name.': instance='.$instance.', type='.$r->type.', t='.$elapsed.'ms, result='.$result->as_log);
+    my $matched = defined $result->last_match ? $result->last_match : '';
+		$self->log(1, $vhost->name.': instance='.$instance.', type='.$r->type.', t='.$elapsed.'ms, plugin='.$matched.', result='.$result->as_log);
 	};
 	if ( $@ ) { $error = $@; }
 
@@ -523,7 +524,7 @@ Mail::MtPolicyd - a modular policy daemon for postfix
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 DESCRIPTION
 
