@@ -3,7 +3,7 @@ package Mail::MtPolicyd::PluginChain;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.19'; # VERSION
+our $VERSION = '1.20'; # VERSION
 # ABSTRACT: class for a VirtualHost instance
 
 use Mail::MtPolicyd::Profiler;
@@ -43,6 +43,9 @@ sub run {
             $r->log(0, $msg);
         }
         Mail::MtPolicyd::Profiler->stop_current_timer;
+    if( scalar @plugin_results ) {
+      $result->last_match( $plugin->name );
+    }
 		foreach my $plugin_result ( @plugin_results ) {
 			$result->add_plugin_result($plugin_result);
 			if( $plugin_result->abort ) {
@@ -137,7 +140,7 @@ Mail::MtPolicyd::PluginChain - class for a VirtualHost instance
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 AUTHOR
 
