@@ -4,7 +4,7 @@ use strict;
 use MooseX::Singleton;
 
 # ABSTRACT: singleton class to hold the sql database connection
-our $VERSION = '1.19'; # VERSION
+our $VERSION = '1.20'; # VERSION
 
 use DBI;
 
@@ -12,25 +12,35 @@ has 'dsn' => ( is => 'ro', isa => 'Str', required => 1 );
 has 'user' => ( is => 'ro', isa => 'Str', required => 1 );
 has 'password' => ( is => 'ro', isa => 'Str', required => 1 );
 
-has 'dbh' => ( is => 'ro', isa => 'DBI::db', lazy => 1,
+has 'dbh' => ( is => 'rw', isa => 'DBI::db', lazy => 1,
     default => sub {
-        my $self = shift;
-        my $dbh = DBI->connect(
-            $self->dsn,
-			$self->user,
-            $self->password,
-            {
-				RaiseError => 1,
-                PrintError => 0,
-				AutoCommit => 1,
-				mysql_auto_reconnect => 1,
-			},
-		);
-        return $dbh;
+      my $self = shift;
+      return $self->_create_dbh;
     },
     handles => [ 'disconnect' ],
 );
 
+sub _create_dbh {
+  my $self = shift;
+  my $dbh = DBI->connect(
+    $self->dsn,
+    $self->user,
+    $self->password,
+    {
+      RaiseError => 1,
+      PrintError => 0,
+      AutoCommit => 1,
+      mysql_auto_reconnect => 1,
+    },
+  );
+  return $dbh;
+}
+
+sub reconnect {
+  my $self = shift;
+  $self->dbh( $self->_create_dbh );
+}
+
 sub is_initialized {
     my ( $class, @args ) = @_;
 
@@ -54,7 +64,7 @@ Mail::MtPolicyd::SqlConnection - singleton class to hold the sql database connec
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 AUTHOR
 
